# Tree sitter grammar for Epidemic Simulator Language (ESL)

Epidemic Simulator Language (ESL)
is a domain specific language for creating
high performance epidemic simulations on networks.

ESL code can be compiled to C++ using
the ESC compiler provided by the ESCAPE framework [1].

[1]: https://github.com/nssac/escape-abm
